@@ -12,7 +12,6 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
     ouroboros_stack_init_ptr
     ouroboros_stack_items_ptr
-    ouroboros_stack_prepush_ptr
     ouroboros_stack_putback_ptr
     ouroboros_stack_fetch_ptr
     ouroboros_stack_store_ptr
@@ -158,7 +157,7 @@ our %EXPORT_TAGS = (
 
 our @EXPORT = qw();
 
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 require XSLoader;
 XSLoader::load('Ouroboros', $VERSION);
@@ -243,12 +242,6 @@ Initialize ouroboros_stack_t object. Must be first thing called by a XS-sub. Equ
 
 Returns number of arguments on Perl stack. Equivalent to C<items> local variable in XS.
 
-=item ouroboros_stack_prepush_ptr
-
-    OUROBOROS_STATIC void ouroboros_stack_prepush(pTHX_ ouroboros_stack_t*);
-
-Perl macro: C<XSprePUSH>
-
 =item ouroboros_stack_putback_ptr
 
     OUROBOROS_STATIC void ouroboros_stack_putback(pTHX_ ouroboros_stack_t*);
