@@ -2,7 +2,7 @@ package Ouroboros::Spec;
 use strict;
 use warnings;
 
-our $VERSION = "0.11";
+our $VERSION = "0.12";
 
 # spec {
 our %SPEC = (
@@ -190,16 +190,6 @@ our %SPEC = (
       },
       "type" => "int"
     },
-    {
-      "c_decl" => "OUROBOROS_STATIC void ouroboros_stack_prepush(pTHX_ ouroboros_stack_t*);",
-      "name" => "ouroboros_stack_prepush",
-      "params" => [
-        "ouroboros_stack_t*"
-      ],
-      "ptr_name" => "ouroboros_stack_prepush_ptr",
-      "tags" => {},
-      "type" => "void"
-    },
     {
       "c_decl" => "OUROBOROS_STATIC void ouroboros_stack_putback(pTHX_ ouroboros_stack_t*);",
       "name" => "ouroboros_stack_putback",
